@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1000';
+our $VERSION = '0.1001';
 
 use Moo;
 use MIDI::Simple;
@@ -157,7 +157,7 @@ sub metronome54 {
         }
         else {
             $self->note($self->eighth, $self->closed_hh);
-            $self->note($self->eighth, $self->closed_hh, $self->kick);
+            $self->note($self->eighth, $self->kick);
         }
     }
 }
@@ -214,7 +214,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1000
+version 0.1001
 
 =head1 SYNOPSIS
 
